@echo off
echo Extract CMORPH Global Precipitation daily
echo Bias corrected and gauge - satellite blended precipitation product from 1998 to 2013
echo Reprocessed, retrieved from ftp://ftp.cpc.ncep.noaa.gov/precip/CMORPH_V1.0/CRT/0.25deg-DLY_00Z/yyyy/yyyymm
echo ftp://ftp.cpc.ncep.noaa.gov/precip/CMORPH_V1.0/CRT/0.25deg-DLY_00Z/1998/199801/CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_19980101.bz2
echo Data available from 1998 onwards
echo Precipitation in mm/24hr
echo file name format CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_19980101.bz2 and after unzip CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_19980101


echo.
echo.

set longfilename=%1
set shortfilename1=%longfilename:~0,8%
set shortfilename2=%longfilename:~0,4%
set shortfilename3=%longfilename:~0,6%


set InputDrive=%2
set InputDir=%3
set OutputDrive=%4
set OutputDir=%5
set gdalDir=%6
set IlwDir=%7
set UtilDir=%8


cd\
%OutputDrive%
cd %OutputDir%

echo your current working directory = %OutputDrive%\%OutputDir%
echo.
echo.

"%UtilDir%\wget\wget.exe" ftp://ftp.cpc.ncep.noaa.gov/precip/CMORPH_V1.0/CRT/0.25deg-DLY_00Z/%shortfilename2%/%shortfilename3%/CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_%shortfilename1%.bz2

echo off
if not exist "%OutputDrive%\%OutputDir%\CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_%shortfilename1%.bz2"  goto MESSAGE
echo The file(s) "CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_%shortfilename1%.bz2" has been retrieved and transferred to your current working directory
echo.
echo.

GOTO START

:MESSAGE
echo The input file was not found in the archive.
echo Check your Date stamp settings
echo Your current Date stamp used is %shortfilename1%
echo Data is retrieved from ftp://ftp.cpc.ncep.noaa.gov/precip/CMORPH_V1.0/CRT/0.25deg-DLY_00Z/yyyy/yyyymm
echo Check also manually if the data exists on ftp archive (see link above)
echo Note that CMORPH data is being reprocessed
echo Further information on the actual status is provided on the ftp location indicated above
echo Internet has a transient nature - addresses might not be valid or has changed after some time!


pause

GOTO END

:START


"%UtilDir%\7z.exe" e CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_%shortfilename1%.bz2

ren "CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_%shortfilename1%" tcmorph025d24hr_%shortfilename1%



rem import layer
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%o:=map('%OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%',genras,Convert,1440,0,Real,4,NoSwap)

rem rotate layer
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%.mpr:=MapMirrorRotate('%OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%o',MirrHor)

rem create subset maps
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%',1,721,480,720)


rem add submap georef

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%_west.mpr %UtilDir%\cmorph025d_west


rem glue maps using georef global

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%1_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%_west,%OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%_east,replace)



rem extract rainfall in mm/24hr and remove undefined

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d24hr_%shortfilename1%:=iff(%OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%1_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d24hr_%shortfilename1%1_recomposed,?)


rem delete obsolete objects

del tcmorph025d24hr_%shortfilename1%
del tcmorph025d24hr_*.mp*
del CMORPH_V1.0_ADJ_0.25deg-DLY_00Z_%shortfilename1%.*


:END
"%IlwDir%\ilwis.exe" -C closeall